
.. NOTES FOR CREATING A RELEASE:
..
..   * bump the version number
..   * update docs/changelog.rst
..   * git push
..   * python setup.py sdist upload
..   * create a release https://github.com/datascopeanalytics/scrubadub/releases


scrubadub
=========

Clean personally identifiable information from dirty dirty text.

`Full documentation <http://scrubadub.readthedocs.org>`__.

|Build Status| |Version| |Downloads| |Test Coverage| |Documentation Status|

.. |Build Status| image:: https://travis-ci.org/datascopeanalytics/scrubadub.svg?branch=master
   :target: https://travis-ci.org/datascopeanalytics/scrubadub
.. |Version| image:: https://pypip.in/v/scrubadub/badge.png
   :target: https://warehouse.python.org/project/scrubadub/
.. |Downloads| image:: https://pypip.in/d/scrubadub/badge.png
   :target: https://warehouse.python.org/project/scrubadub/
.. |Test Coverage| image:: https://coveralls.io/repos/datascopeanalytics/scrubadub/badge.png
   :target: https://coveralls.io/r/datascopeanalytics/scrubadub
.. |Documentation Status| image:: https://readthedocs.org/projects/scrubadub/badge/?version=latest
   :target: https://readthedocs.org/projects/scrubadub/?badge=latest
